Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1049)

Unified Diff: scripts/master/master_config.py

Issue 12033076: Add ChromiumWebRTC FYI waterfall (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/tools/build
Patch Set: Added master to test/masters_test.py Created 7 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « scripts/master/factory/chromium_factory.py ('k') | site_config/config_default.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: scripts/master/master_config.py
diff --git a/scripts/master/master_config.py b/scripts/master/master_config.py
index 254a6a1adade692a34e89f6a8e071c51acb25ef5..e1c21182d9d56c2e819d62036f01721dd92e6771 100644
--- a/scripts/master/master_config.py
+++ b/scripts/master/master_config.py
@@ -4,6 +4,7 @@
from buildbot.scheduler import Dependent
from buildbot.scheduler import Nightly
+from buildbot.scheduler import Periodic
from buildbot.scheduler import Scheduler
from buildbot.scheduler import Triggerable
@@ -57,6 +58,14 @@ class Helper(object):
'branch': branch,
'hour': hour}
+ def Periodic(self, name, periodicBuildTimer):
+ """Helper method for the Periodic scheduler."""
+ if name in self._schedulers:
+ raise ValueError('Scheduler %s already exists' % name)
+ self._schedulers[name] = {'type': 'Periodic',
+ 'builders': [],
+ 'periodicBuildTimer': periodicBuildTimer}
+
def Dependent(self, name, parent):
if name in self._schedulers:
raise ValueError('Scheduler %s already exists' % name)
@@ -109,7 +118,7 @@ class Helper(object):
new_builder['builddir'] = builder['builddir']
c['builders'].append(new_builder)
- # Process the main schedulers
+ # Process the main schedulers.
for s_name in self._schedulers:
scheduler = self._schedulers[s_name]
if scheduler['type'] == 'Scheduler':
@@ -121,7 +130,7 @@ class Helper(object):
scheduler['instance'] = instance
c['schedulers'].append(instance)
- # Process the dependent schedulers
+ # Process the dependent schedulers.
for s_name in self._schedulers:
scheduler = self._schedulers[s_name]
if scheduler['type'] == 'Dependent':
@@ -130,14 +139,23 @@ class Helper(object):
self._schedulers[scheduler['parent']]['instance'],
scheduler['builders']))
- # Process the triggerable schedulers
+ # Process the triggerable schedulers.
for s_name in self._schedulers:
scheduler = self._schedulers[s_name]
if scheduler['type'] == 'Triggerable':
c['schedulers'].append(Triggerable(s_name,
scheduler['builders']))
- # Process the nightly schedulers
+ # Process the periodic schedulers.
+ for s_name in self._schedulers:
+ scheduler = self._schedulers[s_name]
+ if scheduler['type'] == 'Periodic':
+ c['schedulers'].append(
+ Periodic(s_name,
+ periodicBuildTimer=scheduler['periodicBuildTimer'],
+ builderNames=scheduler['builders']))
+
+ # Process the nightly schedulers.
for s_name in self._schedulers:
scheduler = self._schedulers[s_name]
if scheduler['type'] == 'Nightly':
« no previous file with comments | « scripts/master/factory/chromium_factory.py ('k') | site_config/config_default.py » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698